@@ -11,6 +11,14 @@ test_that("Import from CSV", {
     expect_that(colnames(noheadercsv)[1], equals("V1"), label = "Header is correctly specified")
 })
 
+test_that("Import from (European-style) CSV with semicolon separator", {
+  write.table(iris, "iris2.csv", dec = ",", sep = ";")
+  expect_true("iris2.csv" %in% dir())
+  expect_true(is.data.frame(import("iris2.csv", dec = ",", sep = ";", fread = TRUE, header = TRUE)))
+  expect_true(is.data.frame(import("iris2.csv", dec = ",", sep = ";", fread = FALSE, header = TRUE)))
+})
+
+
 context("CSV (.csv2) imports/exports")
 
 test_that("Export to CSV", {
@@ -39,3 +47,4 @@ test_that("Import from TSV with CSV extension", {
 })
 
 unlink("iris.csv")
+unlink("iris2.csv")
