@@ -7,11 +7,11 @@ require("datasets")
 
 test_that("Export to Excel (.xlsx)", {
     expect_true(export(iris, "iris.xlsx") %in% dir())
-    
 })
 
 test_that("Import from Excel (.xlsx)", {
-    expect_true(is.data.frame(import("iris.xlsx")))
+    expect_true(is.data.frame(import("iris.xlsx", readxl = FALSE)))
+    expect_true(is.data.frame(import("iris.xlsx", readxl = TRUE)))
 })
 
 unlink("iris.xlsx")
